@@ -359,4 +359,42 @@ class ManageCommand(ShowCommand):
                 print(f"No delegations found for Broker# {broker}")
         except Exception as e:
             self.logger.error(f"Exception occurred e: {e}")
-            self.logger.error(traceback.format_exc())
\ No newline at end of file
+            self.logger.error(traceback.format_exc())
+
+    def toggle_maintenance_mode(self, *, actor_name: str, callback_topic: str, mode: bool = False,
+                                id_token: str = None):
+        """
+        Claim delegations
+        @param actor_name actor name
+        @param callback_topic callback topic
+        @param mode mode
+        @param id_token id token
+        """
+        status = False
+        error = ""
+        try:
+            actor = self.get_actor(actor_name=actor_name)
+
+            if actor is None:
+                raise Exception(f"Invalid arguments! {actor_name} not found")
+
+            try:
+                actor.prepare(callback_topic=callback_topic)
+
+                status = actor.toggle_maintenance_mode(actor_guid=str(actor.get_guid()),
+                                                       mode=mode, callback_topic=callback_topic,
+                                                       id_token=id_token)
+            except Exception as e:
+                self.logger.error(f"Exception occurred e: {e}")
+                self.logger.error(traceback.format_exc())
+
+            error = actor.get_last_error()
+        except Exception as e:
+            self.logger.error(f"Exception occurred e: {e}")
+            self.logger.error(traceback.format_exc())
+            error = str(e)
+
+        if status:
+            print(f"Maintenance mode successfully set to {mode}")
+        else:
+            print(f"Failure to set maintenance mode error {error}")
